/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * JBoss, Home of Professional Open Source
 * Copyright 2012 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.hibernate.search.test.configuration;

import org.hibernate.search.impl.MutableSearchFactory;
import org.hibernate.search.test.util.ManualConfiguration;

import org.junit.Test;

import static junit.framework.Assert.assertEquals;


/**
 * Verifies the global setting from {@link org.hibernate.search.cfg.spi.SearchConfiguration#isIndexMetadataComplete()}
 * affect the backends as expected.
 *
 * @author Sanne Grinovero <sanne@hibernate.org> (C) 2012 Red Hat Inc.
 */
public class IndexMetadataCompleteConfiguredTest extends BaseConfigurationTest {

	@Test
	public void testDefaultImplementation() {
		ManualConfiguration cfg = new ManualConfiguration();
		verifyIndexCompleteMetadataOption( true, cfg );
	}

	@Test
	public void testIndexMetadataCompleteFalse() {
		ManualConfiguration cfg = new ManualConfiguration();
		cfg.setIndexMetadataComplete( false );
		verifyIndexCompleteMetadataOption( false, cfg );
	}

	@Test
	public void testIndexMetadataCompleteTrue() {
		ManualConfiguration cfg = new ManualConfiguration();
		cfg.setIndexMetadataComplete( true );
		verifyIndexCompleteMetadataOption( true, cfg );
	}

	private void verifyIndexCompleteMetadataOption(boolean expectation, ManualConfiguration cfg) {
		MutableSearchFactory sf = getMutableSearchFactoryWithSingleEntity( cfg );
		try {
			assertEquals( expectation, extractWorkspace( sf, Document.class ).areSingleTermDeletesSafe() );

			// trigger a SearchFactory rebuild:
			sf.addClasses( Dvd.class, Book.class );
			// DVD share the same index, so now it's always unsafe [always false no matter the global option]
			assertEquals( false, extractWorkspace( sf, Dvd.class ).areSingleTermDeletesSafe() );
			assertEquals( false, extractWorkspace( sf, Document.class ).areSingleTermDeletesSafe() );

			// but still as expected for Book :
			assertEquals( expectation, extractWorkspace( sf, Book.class ).areSingleTermDeletesSafe() );
		}
		finally {
			sf.close();
		}
	}

}
